<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch">
      <el-form-item label="岗位编号" prop="postNo">
        <el-input
          v-model="queryParams.postNo"
          placeholder="请输入岗位编号"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="审批组名" prop="postName">
        <el-input
          v-model="queryParams.postName"
          placeholder="请输入审批组名"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="审批级别" prop="postLevel">
        <el-select v-model="queryParams.postLevel" placeholder="请选择审批级别" clearable size="small">
          <el-option
            v-for="dict in dict.type.post_level"
            :key="dict.value"
            :label="dict.label"
            :value="dict.value"
          />
        </el-select>
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['system:postConfig:add']"
        >新增
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['system:postConfig:edit']"
        >修改
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['system:postConfig:remove']"
        >删除
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          :loading="exportLoading"
          @click="handleExport"
          v-hasPermi="['system:postConfig:export']"
        >导出
        </el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="postConfigList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center"/>
      <!--      <el-table-column label="岗位编号" align="center" prop="postNo"/>-->
      <el-table-column label="审批组名" align="center" prop="postName"/>
      <el-table-column label="审批级别" align="center" prop="postLevel">
        <template slot-scope="scope">
          <dict-tag :options="dict.type.post_level" :value="scope.row.postLevel"/>
        </template>
      </el-table-column>
      <el-table-column label="组成员" align="center" prop="postUserG"/>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-plus"
            @click="addMembers(scope.row)"
          >配置成员
          </el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['system:postConfig:edit']"
          >修改
          </el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['system:postConfig:remove']"
          >删除
          </el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改岗位配置对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="600px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules">
        <!--        <el-form-item label="岗位编号" prop="postNo">-->
        <!--          <el-input v-model="form.postNo" placeholder="请输入岗位编号"/>-->
        <!--        </el-form-item>-->
        <el-form-item label="审批组名" prop="postName">
          <el-input v-model="form.postName" placeholder="请输入审批组名"/>
        </el-form-item>
        <el-form-item label="审批级别" prop="postLevel">
          <el-select v-model="form.postLevel" placeholder="请选择审批级别">
            <el-option
              v-for="dict in dict.type.post_level"
              :key="dict.value"
              :label="dict.label"
              :value="dict.value"
            ></el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="备注" prop="remark">
          <el-input v-model="form.remark" placeholder="请输入备注"/>
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>

    <el-dialog :title="userListDialog.title" :visible.sync="userListDialog.open" width="1500px" append-to-body>
      <el-form :model="userListDialog" ref="queryForm" :inline="true" v-show="showSearch">
        <el-form-item label="姓名" prop="userName">
          <el-input
            v-model="userListDialog.userName"
            placeholder="请输入姓名"
            clearable
            size="small"
            @keyup.enter.native="handleQuery"
          />
        </el-form-item>
        <el-form-item>
          <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery2">搜索</el-button>
        </el-form-item>
      </el-form>
      <el-row :gutter="50" class="mb8">
        <el-col :span="14">
          <el-row :gutter="10" class="mb8">
            <el-col :span="1.5">
              <el-button
                type="primary"
                plain
                icon="el-icon-plus"
                size="mini"
                @click="addGroupUser"
              >添加
              </el-button>
            </el-col>
            <right-toolbar :showSearch.sync="showSearch" @queryTable="getUserDialogList"></right-toolbar>
          </el-row>
          <el-table :title="titleText" v-loading="userListDialog.loading" :data="filesList" @cancel="cancel"
                    @selection-change="addConfigUser">
            <el-table-column type="selection" width="55" align="center"/>
            <el-table-column label="用户编号" align="center" prop="userCode"/>
            <el-table-column label="工号" align="center" prop="jobNo"/>
            <el-table-column label="姓名" align="center" prop="userName"/>
          </el-table>
          <pagination
            v-show="userListDialog.total>0"
            :total="userListDialog.total"
            :page.sync="userListDialog.pageNum"
            :limit.sync="userListDialog.pageSize"
            @pagination="getUserDialogList"
          />
        </el-col>
        <el-col :span="10">
          <el-table :title="titleText" v-loading="userListDialog.loading" :data="userActualList" @cancel="cancel">
            <el-table-column label="用户编号" align="center" prop="userCode"/>
            <el-table-column label="姓名" align="center" prop="userName"/>
            <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
              <template slot-scope="scope">
                <el-button
                  size="mini"
                  type="text"
                  icon="el-icon-delete"
                  @click="deletePostUser(scope.row,scope.$index)"
                  v-hasPermi="['system:postConfig:remove']"
                >删除
                </el-button>
              </template>
            </el-table-column>
          </el-table>
        </el-col>
      </el-row>

    </el-dialog>
  </div>
</template>

<script>
import {
  listPostConfig,
  getPostConfig,
  delPostConfig,
  addPostConfig,
  updatePostConfig,
  exportPostConfig
} from "@/api/system/postConfig";
import {listFiles} from "@/api/files/files";
import {addUser} from "@/api/clocking/groupconfig";

export default {
  name: "PostConfig",
  dicts: ['post_level'],
  data() {
    return {
      // 遮罩层
      loading: true,
      titleText: '',
      // 导出遮罩层
      exportLoading: false,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 岗位配置表格数据
      postConfigList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        postNo: null,
        postName: null,
        postLevel: null,
        postUserG: null,
        isDelete: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {},
      userListDialog: {
        open: false,
        title: '人员配置',
        total: 0,
        loading: true,
        pageNum: 1,
        pageSize: 10
      },
      filesList: [],
      userActualList: []
    };
  },
  created() {
    this.getList();
    this.getUserDialogList()
  },
  methods: {
    /** 搜索按钮操作 */
    handleQuery2() {
      this.userListDialog.pageNum = 1
      this.getUserDialogList()
    },
    /** 添加用户按钮 */
    addGroupUser() {
      let postUserG = this.form.postUserG
      let postUserGSplit = []
      if (postUserG) {
        postUserGSplit = postUserG.split(',')
      }
      for (let i = 0; i < this.ids.length; i++) {
        postUserGSplit.unshift(this.ids[i])
      }
      this.form.postUserG = postUserGSplit.toString();
      updatePostConfig(this.form).then(() => {
        this.ids = []
        this.setUserActualList()
        this.$modal.msgSuccess("添加成功");
        this.open = false;
        this.getList();
      });
    },
    deletePostUser(item, index) {
      let reg
      debugger
      if (index > 0) {
        reg = new RegExp("," + item.userName + item.userCode)
      } else if (index === 0 && this.userActualList.length === 1) {
        reg = new RegExp(item.userName + item.userCode)
      } else {
        reg = new RegExp(item.userName + item.userCode + ',')
      }
      this.form.postUserG = this.form.postUserG.replace(reg, "");
      this.setUserActualList()
      updatePostConfig(this.form).then(() => {
        this.$modal.msgSuccess("删除成功");
        this.open = false;
        this.getList();
      });
    },
    addMembers(item) {
      this.userListDialog.open = true
      this.form = item
      this.setUserActualList()
    },
    setUserActualList() {
      this.userActualList = []
      let ay = this.form.postUserG.split(",")
      if (ay) {
        for (let i = 0; i < ay.length; i++) {
          let of = ay[i].indexOf("AA");
          if (of !== -1) {
            this.userActualList.push({
              userName: ay[i].substring(0, of),
              userCode: ay[i].substring(of)
            })
          } else {
            of = ay[i].indexOf('admin');
            if (of !== -1) {
              this.userActualList.push({
                userName: "WILLALP",
                userCode: "admin"
              })
            }
          }
        }
      }
    },
    /** 查询岗位配置列表 */
    getList() {
      this.loading = true;
      listPostConfig(this.queryParams).then(response => {
        this.postConfigList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        postNo: null,
        postName: null,
        postLevel: null,
        postUserG: null,
        isDelete: null,
        createBy: null,
        createTime: null,
        updateBy: null,
        updateTime: null,
        remark: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 多选框选中数据
    addConfigUser(selection) {
      this.ids = selection.map(item => item.userName + item.userCode)
      this.single = selection.length !== 1
      this.multiple = !selection.length
    },
    /** 查询机构人员档案列表 */
    getUserDialogList() {
      this.userListDialog.loading = true
      listFiles(this.userListDialog).then(response => {
        this.filesList = response.rows
        this.userListDialog.total = response.total
        this.userListDialog.loading = false
      })
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length !== 1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加岗位配置";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getPostConfig(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改岗位配置";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updatePostConfig(this.form).then(() => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addPostConfig(this.form).then(() => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除岗位配置编号为"' + ids + '"的数据项？').then(function () {
        return delPostConfig(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {
      });
    },
    /** 导出按钮操作 */
    handleExport() {
      const queryParams = this.queryParams;
      this.$modal.confirm('是否确认导出所有岗位配置数据项？').then(() => {
        this.exportLoading = true;
        return exportPostConfig(queryParams);
      }).then(response => {
        this.$download.name(response.msg);
        this.exportLoading = false;
      }).catch(() => {
      });
    }
  }
};
</script>
